==> qmmp_1.2.6.orig.tar.bz2: qmmp-1.2.6/src/plugins/General/scrobbler/translations/scrobbler_plugin_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="id">
<context>
    <name>ScrobblerFactory</name>
    <message>
        <location filename="../scrobblerfactory.cpp" line="31"/>
        <source>Scrobbler Plugin</source>
        <translation>Plugin Scrobbler</translation>
    </message>
    <message>
        <location filename="../scrobblerfactory.cpp" line="51"/>
        <source>About Scrobbler Plugin</source>
        <translation>Tentang Plugin Scrobbler</translation>
    </message>
    <message>
        <location filename="../scrobblerfactory.cpp" line="52"/>
        <source>Qmmp AudioScrobbler Plugin</source>
        <translation>Plugin AudioScrobbler Qmmp</translation>
    </message>
    <message>
        <location filename="../scrobblerfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Scrobbler Plugin Settings</source>
        <translation>Setelan Plugin Scrobbler</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Last.fm</source>
        <translation>Last.fm</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="40"/>
        <location filename="../settingsdialog.ui" line="113"/>
        <source>Session:</source>
        <translation>Sesi:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="50"/>
        <location filename="../settingsdialog.ui" line="126"/>
        <source>Check</source>
        <translation>Periksa</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="72"/>
        <location filename="../settingsdialog.ui" line="104"/>
        <source>Register new session</source>
        <translation>Registrasi sesi baru</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="82"/>
        <source>Libre.fm</source>
        <translation>Libre.fm</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="86"/>
        <location filename="../settingsdialog.cpp" line="121"/>
        <location filename="../settingsdialog.cpp" line="172"/>
        <source>Message</source>
        <translation>Pesan</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="87"/>
        <source>1. Wait for browser startup</source>
        <translation>1. Tunggu browser startup</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="88"/>
        <source>2. Allow Qmmp to scrobble tracks to your %1 account</source>
        <translation>2. Bolehkan Qmmp untuk scrobble track ke akun %1 kamu</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="90"/>
        <source>3. Press &quot;OK&quot;</source>
        <translation>3. Tekan &quot;OK&quot;</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="103"/>
        <location filename="../settingsdialog.cpp" line="107"/>
        <location filename="../settingsdialog.cpp" line="136"/>
        <location filename="../settingsdialog.cpp" line="140"/>
        <location filename="../settingsdialog.cpp" line="180"/>
        <location filename="../settingsdialog.cpp" line="184"/>
        <source>Error</source>
        <translation>Galat</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="103"/>
        <location filename="../settingsdialog.cpp" line="136"/>
        <location filename="../settingsdialog.cpp" line="180"/>
        <source>Network error</source>
        <translation>Galat jaringan</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="107"/>
        <location filename="../settingsdialog.cpp" line="140"/>
        <source>Unable to register new session</source>
        <translation>Tak dapat meregistrasi sesi baru</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="121"/>
        <source>New session has been received successfully</source>
        <translation>Sesi baru telah diterima dengan sukses</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="172"/>
        <source>Permission granted</source>
        <translation>Perizinan dikabulkan</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="184"/>
        <source>Permission denied</source>
        <translation>Perizinan ditolak</translation>
    </message>
</context>
</TS>

==> qmmp_1.3.1.orig.tar.bz2: qmmp-1.3.1/src/plugins/General/scrobbler/translations/scrobbler_plugin_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="id">
<context>
    <name>ScrobblerFactory</name>
    <message>
        <location filename="../scrobblerfactory.cpp" line="31"/>
        <source>Scrobbler Plugin</source>
        <translation>Plugin Scrobbler</translation>
    </message>
    <message>
        <location filename="../scrobblerfactory.cpp" line="51"/>
        <source>About Scrobbler Plugin</source>
        <translation>Tentang Plugin Scrobbler</translation>
    </message>
    <message>
        <location filename="../scrobblerfactory.cpp" line="52"/>
        <source>Qmmp AudioScrobbler Plugin</source>
        <translation>Plugin AudioScrobbler Qmmp</translation>
    </message>
    <message>
        <location filename="../scrobblerfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Ditulis oleh: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Scrobbler Plugin Settings</source>
        <translation>Setelan Plugin Scrobbler</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="20"/>
        <source>Last.fm</source>
        <translation>Last.fm</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="31"/>
        <location filename="../settingsdialog.ui" line="104"/>
        <location filename="../settingsdialog.ui" line="160"/>
        <source>Session:</source>
        <translation>Sesi:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <location filename="../settingsdialog.ui" line="117"/>
        <location filename="../settingsdialog.ui" line="173"/>
        <source>Check</source>
        <translation>Periksa</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="63"/>
        <location filename="../settingsdialog.ui" line="95"/>
        <location filename="../settingsdialog.ui" line="151"/>
        <source>Register new session</source>
        <translation>Registrasi sesi baru</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="73"/>
        <source>Libre.fm</source>
        <translation>Libre.fm</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="129"/>
        <source>ListenBrainz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="126"/>
        <location filename="../settingsdialog.cpp" line="152"/>
        <location filename="../settingsdialog.cpp" line="217"/>
        <source>Message</source>
        <translation>Pesan</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="127"/>
        <source>1. Wait for browser startup</source>
        <translation>1. Tunggu browser startup</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="128"/>
        <source>2. Allow Qmmp to scrobble tracks to your %1 account</source>
        <translation>2. Bolehkan Qmmp untuk scrobble track ke akun %1 kamu</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="129"/>
        <source>3. Press &quot;OK&quot;</source>
        <translation>3. Tekan &quot;OK&quot;</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="134"/>
        <location filename="../settingsdialog.cpp" line="138"/>
        <location filename="../settingsdialog.cpp" line="172"/>
        <location filename="../settingsdialog.cpp" line="176"/>
        <location filename="../settingsdialog.cpp" line="227"/>
        <location filename="../settingsdialog.cpp" line="231"/>
        <source>Error</source>
        <translation>Galat</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="134"/>
        <location filename="../settingsdialog.cpp" line="172"/>
        <location filename="../settingsdialog.cpp" line="227"/>
        <source>Network error</source>
        <translation>Galat jaringan</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="138"/>
        <location filename="../settingsdialog.cpp" line="176"/>
        <source>Unable to register new session</source>
        <translation>Tak dapat meregistrasi sesi baru</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="152"/>
        <source>New session has been received successfully</source>
        <translation>Sesi baru telah diterima dengan sukses</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="217"/>
        <source>Permission granted</source>
        <translation>Perizinan dikabulkan</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="231"/>
        <source>Permission denied</source>
        <translation>Perizinan ditolak</translation>
    </message>
</context>
</TS>
